Module input_output

Module input_output 

Functions

check_output
Check the output directory pass in argument of the program Check if the folder exist, if not create it Return an error if it’s not possible, or in case of wrong permissions access
write_file