check_output

Function check_output 

pub fn check_output(output: &str) -> Result<PathBuf, Error>
Check the output directory pass in argument of the program Check if the folder exist, if not create it Return an error if it’s not possible, or in case of wrong permissions access