Module input_output
pdbget
1.0.1
Module input_
output
Module Items
Functions
In crate pdbget
pdbget
Module
input_
output
Functions

check_
output
Check the output directory pass in argument of the program Check if the folder exist, if not create it Return an error if it’s not possible, or in case of wrong permissions access
write_
file